@@ -17,6 +17,7 @@ import org.gcube.portal.databook.shared.Notification;
 import org.gcube.portal.databook.shared.NotificationChannelType;
 import org.gcube.portal.databook.shared.NotificationType;
 import org.gcube.portal.databook.shared.PrivacyLevel;
+import org.gcube.portal.databook.shared.RangeFeeds;
 import org.gcube.portal.databook.shared.ex.ColumnNameNotFoundException;
 import org.gcube.portal.databook.shared.ex.CommentIDNotFoundException;
 import org.gcube.portal.databook.shared.ex.FeedIDNotFoundException;
@@ -630,6 +631,49 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 		}
 		return toReturn;
 	}
+	/**
+	 * {@inheritDoc}
+	 */
+	@Override
+	public RangeFeeds getRecentFeedsByVREAndRange(String vreid, int from, int quantity) throws IllegalArgumentException, PrivacyLevelTypeNotFoundException,	FeedTypeNotFoundException, ColumnNameNotFoundException, FeedIDNotFoundException {
+		if (from < 1) {
+			throw new IllegalArgumentException("From must be greather than 0");
+		} 
+		ArrayList<Feed> feedsToReturn = new ArrayList<Feed>();
+		ArrayList<String> feedIDs = getVREFeedIds(vreid);
+		
+		//if from is greater than feeds size return empty
+		if (from >=  feedIDs.size()) {
+			_log.warn("The starting point of the range is greather than the total number of feeds for this timeline: " + from + " >= " + feedIDs.size());
+			return new RangeFeeds();
+		}
+		
+		int rangeStart = feedIDs.size()-from;
+		int rangeEnd = rangeStart-quantity;
+		
+		//check that you reached the end
+		if (rangeEnd<1)
+			rangeEnd = 0;
+		
+		_log.debug("BEFORE starting Point=" + rangeStart + " rangeEnd= " + rangeEnd);
+		//need them in reverse order		
+		int howMany = from;
+		for (int i = rangeStart; i > rangeEnd; i--) {
+			Feed toAdd = readFeed(feedIDs.get(i));
+			if (toAdd.getType() == FeedType.TWEET || toAdd.getType() == FeedType.SHARE || toAdd.getType() == FeedType.PUBLISH) {
+				feedsToReturn.add(toAdd);
+				_log.trace("Read recent feed, i=" + i + " id= " + feedIDs.get(i));
+			} else {
+				_log.trace("Read and skipped feed, i=" + i + " id=: " + feedIDs.get(i) + " (Removed Feed) .");
+				rangeEnd -= 1; //increase the upTo in case of removed feed
+				//check if quantity is greater than user feeds
+				rangeEnd = (rangeEnd > 0) ? rangeEnd : 0;
+			}
+			howMany++;
+		}
+		_log.debug("AFTER: starting Point==" + rangeStart + " rangeEnd= " + rangeEnd);
+		return new RangeFeeds(howMany+1, feedsToReturn);
+	}
 	/**
 	 * get a list of user vre feed UUIDs in chronological order from the oldest to the more recent
 	 * @param vreid  vreid identifier (scope)
